==> mantra.1.7.6.zip: mantra/admin/mantra-defaults.php <==
<?php

// DEFAULT OPTIONS ARRAY

$mantra_defaults = array(

"mantra_side" => "2cSr",
"mantra_sidewidth" => 800,
"mantra_sidebar" => 250,
"mantra_hheight" => "120px",

"mantra_fontfamily" => 'Segoe UI, Arial, sans-serif',
"mantra_fontsize" => "15px",
"mantra_fonttitle" => 'Default',
"mantra_headfontsize" => "Default",
"mantra_fontside" => 'Default',
"mantra_sidefontsize" => "Default",
"mantra_fontsubheader" => 'Default',
"mantra_textalign" => "Default",
"mantra_parindent" => "0px",
"mantra_headerindent" => "Enable",
"mantra_lineheight" => "Default",
"mantra_wordspace" => "Default",
"mantra_letterspace" => "Default",
"mantra_textshadow" => "Enable",


"mantra_backcolor" => "#444444",
"mantra_headercolor" => "#333333",
"mantra_prefootercolor" => "#222222",
"mantra_footercolor" => "#171717",
"mantra_titlecolor" => "#0D85CC",
"mantra_descriptioncolor" => "#999999",
"mantra_contentcolor" => "#333333",
"mantra_linkscolor" => "#0D85CC",
"mantra_hovercolor" => "#333333",
"mantra_headtextcolor" => "#333333",
"mantra_headtexthover" => "#000000",
"mantra_sideheadbackcolor" => "#444444",
"mantra_sideheadtextcolor" => "#2EA5FD",

"mantra_footerheader" => "#0C85CD",
"mantra_footertext" => "#666666",
"mantra_footerhover" => "#888888",

"mantra_caption" => "Light",
"mantra_image" => "Seven",
"mantra_pin" => "Pin2",
"mantra_sidebullet" => "arrow_white",
"mantra_metaback" => "Gray",
"mantra_contentlist" => "Show",
"mantra_title" => "Show",
"mantra_pagetitle" => "Show",
"mantra_categtitle" => "Show",
"mantra_tables" => "Disable",
"mantra_backtop" => "Enable",
"mantra_comtext" => "Show",
"mantra_comclosed" => "Show",
"mantra_comoff" => "Show",
"mantra_copyright" => "",

"mantra_postdate" => "Show",
"mantra_posttime" => "Hide",
"mantra_postauthor" => "Show",
"mantra_postcateg" => "Show",
"mantra_posttag" => "Show",
"mantra_postbook" => "Show",

"mantra_excerpthome" => "Full Post",
"mantra_excerptarchive" => "Full Post",
"mantra_excerptwords" => "50",
"mantra_excerptdots" => " &hellip;",
"mantra_excerptcont" => " Continue reading",

"mantra_fpost" => "Disable",
"mantra_fauto" => "Disable",
"mantra_falign" => "Left",
"mantra_fwidth" => "250",
"mantra_fheight" => "150",
"mantra_fheader" => "Disable",

"mantra_social1" => "",
"mantra_social2" => "",
"mantra_social3" => "",
"mantra_social4" => "",
"mantra_social5" => "",
"mantra_social6" => "",
"mantra_social7" => "",
"mantra_social8" => "",
"mantra_social9" => "",
"mantra_social10" => "",
"mantra_socialsdisplay0" => "",
"mantra_socialsdisplay1" => "",
"mantra_socialsdisplay2" => "",
"mantra_socialsdisplay3" => "",

"mantra_customcss" => "/* Mantra Custom CSS */  ");

?>

==> mantra.1.8.0.zip: mantra/admin/mantra-defaults.php <==
<?php

// DEFAULT OPTIONS ARRAY

$mantra_defaults = array(

"mantra_side" => "2cSr",
"mantra_dimselect" => 'Absolute',
"mantra_sidewidth" => 800,
"mantra_sidebar" => 250,
"mantra_sidewidthRel" => 60,
"mantra_sidebarRel" => 20,
"mantra_hheight" => "120px",

"mantra_fontfamily" => 'Segoe UI, Arial, sans-serif',
"mantra_fontsize" => "15px",
"mantra_fonttitle" => 'Default',
"mantra_headfontsize" => "Default",
"mantra_fontside" => 'Default',
"mantra_sidefontsize" => "Default",
"mantra_fontsubheader" => 'Default',
"mantra_textalign" => "Default",
"mantra_parindent" => "0px",
"mantra_headerindent" => "Enable",
"mantra_lineheight" => "Default",
"mantra_wordspace" => "Default",
"mantra_letterspace" => "Default",
"mantra_textshadow" => "Enable",


"mantra_backcolor" => "#444444",
"mantra_headercolor" => "#333333",
"mantra_prefootercolor" => "#222222",
"mantra_footercolor" => "#171717",
"mantra_titlecolor" => "#0D85CC",
"mantra_descriptioncolor" => "#999999",
"mantra_contentcolor" => "#333333",
"mantra_linkscolor" => "#0D85CC",
"mantra_hovercolor" => "#333333",
"mantra_headtextcolor" => "#333333",
"mantra_headtexthover" => "#000000",
"mantra_sideheadbackcolor" => "#444444",
"mantra_sideheadtextcolor" => "#2EA5FD",

"mantra_footerheader" => "#0C85CD",
"mantra_footertext" => "#666666",
"mantra_footerhover" => "#888888",

"mantra_caption" => "Light",
"mantra_image" => "Seven",
"mantra_pin" => "Pin2",
"mantra_sidebullet" => "arrow_white",
"mantra_metaback" => "Gray",
"mantra_contentlist" => "Show",
"mantra_title" => "Show",
"mantra_pagetitle" => "Show",
"mantra_categtitle" => "Show",
"mantra_tables" => "Disable",
"mantra_backtop" => "Enable",
"mantra_comtext" => "Show",
"mantra_comclosed" => "Show",
"mantra_comoff" => "Show",
"mantra_copyright" => "",

"mantra_postdate" => "Show",
"mantra_posttime" => "Hide",
"mantra_postauthor" => "Show",
"mantra_postcateg" => "Show",
"mantra_posttag" => "Show",
"mantra_postbook" => "Show",
"mantra_postmetas" => "Show",

"mantra_excerpthome" => "Full Post",
"mantra_excerptarchive" => "Full Post",
"mantra_excerptwords" => "50",
"mantra_excerptdots" => " &hellip;",
"mantra_excerptcont" => " Continue reading",

"mantra_fpost" => "Disable",
"mantra_fauto" => "Disable",
"mantra_falign" => "Left",
"mantra_fwidth" => "250",
"mantra_fheight" => "150",
"mantra_fheader" => "Disable",

"mantra_social1" => "",
"mantra_social2" => "",
"mantra_social3" => "",
"mantra_social4" => "",
"mantra_social5" => "",
"mantra_social6" => "",
"mantra_social7" => "",
"mantra_social8" => "",
"mantra_social9" => "",
"mantra_social10" => "",
"mantra_socialsdisplay0" => "",
"mantra_socialsdisplay1" => "",
"mantra_socialsdisplay2" => "",
"mantra_socialsdisplay3" => "",

"mantra_linkheader" => "Disable",
"mantra_faviconshow" => "Disable",
"mantra_favicon" => "",
"mantra_customcss" => "/* Mantra Custom CSS */  ");

?>
